#!/usr/bin/python3
from backup_manager import BackupManager
import sys, getopt
import os

###############################################################################
# This function prints help
def print_help(name):
  print(name + ' [option]')
  print('Options:')
  print('-d, --default\tuse defaults (-i all -o /tmp/wavpn_backup/backup.tar.gz -q -f)')
  print('-f, --force\toverwrites output file without asking.')
  print('-h, --help\tprints help')
  print('-i, --input\tspecify what to back up: cs, ds or all')
  print('-o, --output\toutput file')
  print('-q, --quiet\tdon\'t print output')

###############################################################################
# This function parses options and returns the result in dictionary.
def parse_options(argv):
  options = { 'd': False, 'f': False, 'h': False, 'q': False, 'o': None, 'i': None}

  try:
    opts, args = getopt.getopt(argv,"dfhqo:i:",['default', 'force', 'help', 'quiet', 'output=', 'input='])
  except getopt.GetoptError:
    print_help(sys.argv[0])
    sys.exit(1)

  for opt, arg in opts:
    if opt in ('-d', '--default'):
      options['d'] = True
    elif opt in ('-f', '--force'):
      options['f'] = True
    if opt in ('-h', '--help'):
      options['h'] = True
    elif opt in ('-q', '--quiet'):
      options['q'] = True
    elif opt in ('-o', '--output'):
      options['o'] = arg
    elif opt in ('-i', '--input'):
      options['i'] = arg

  # Manage default option
  if options['d'] == True:
    options['q'] = True
    options['i'] = 'all'
    options['o'] = None
    options['f'] = True

  return options

###############################################################################
# This function checks options.
def check_options(options):
  # Check if backup input was given.
  if not (options['i'] in ('cs', 'ds', 'all')):
    print('Specify input for backup (cs, ds, all).')
    sys.exit(1)


if __name__== "__main__":
  # If no arguments were given, print help.
  if len(sys.argv) == 1:
    print_help(sys.argv[0])
    sys.exit(1)

  # Parse options.
  options = parse_options(sys.argv[1:])

  # Print help if -h was introduced on command line.
  if options['h'] == True:
    print_help(sys.argv[0])
    sys.exit(0)

  # Check options. This function exists if options are not ok.
  check_options(options)

  # Determine output path and file.
  if options['o'] != None and len(options['o']) > 0:
    path, file_out = os.path.split(options['o'])
    # Use current directory if path was not given.
    if len(path) == 0:
      path = '.'
    bm = BackupManager(backup_path = path, backup_file = file_out, quiet = options['q'], force = options['f'])
  else:
    bm = BackupManager(quiet = options['q'], force = options['f'])

  try:
    if options['i'] == 'cs':
      bm.backup_cs()
    elif options['i'] == 'ds':
      bm.backup_ds()
    elif options['i'] == 'all':
      bm.backup_all()

  except Exception as e:
    print("Error: " + str(e), file = sys.stderr)
