#!/usr/bin/python3
from backup_manager import BackupManager
import sys, getopt, os

###############################################################################
# This function prints help
def print_help(name):
  print(name + ' [option]')
  print('Options:')
  print('-d, --default\tuse defaults (-i /tmp/wavpn_backup/backup.tar.gz -q)')
  print('-f, --force\tnot implemented yet')
  print('-h, --help\tprints help')
  print('-i, --input\tinput file')
  print('-n, --no-clean\tdon\'t clean target directories before update')
  print('-q, --quiet\tdon\'t print output')
  print('-r, --remove\tremoves the backup file after restore')

###############################################################################
# This function parses options and returns the result in dictionary.
def parse_options(argv):
  options = {'d': False, 'f': False, 'h': False, 'n': False, 'q': False, 'r': False, 'i': None}

  try:
    opts, args = getopt.getopt(argv,"dfhnqri:",['default', 'force', 'help', 'no-clean', 'quiet', 'remove', 'input='])
  except getopt.GetoptError:
    print_help(sys.argv[0])
    sys.exit(1)

  for opt, arg in opts:
    if opt in ('-d', '--default'):
      options['d'] = True
    elif opt in ('-f', '--force'):
      options['f'] = True
    elif opt in ('-h', '--help'):
      options['h'] = True
    elif opt in ('-n', '--no-clean'):
      options['n'] = True
    elif opt in ('-q', '--quiet'):
      options['q'] = True
    elif opt in ('-r', '--remove'):
      options['r'] = True
    elif opt in ('-i', '--input'):
      options['i'] = arg

  # Manage option default (-d)
  if options['d'] == True:
    options['q'] == True
    options['i'] == None
  return options

if __name__== "__main__":
  # If no arguments were given, print help.
  if len(sys.argv) == 1:
    print_help(sys.argv[0])
    sys.exit(1)

  # Parse options.
  options = parse_options(sys.argv[1:])

  # Print help if -h was introduced on command line.
  if options['h'] == True:
    print_help(sys.argv[0])
    sys.exit(0)

  # Determine output path and file.
  if options['i'] != None and len(options['i']) > 0:
    path, file_out = os.path.split(options['i'])
    # Use current directory if path was not given.
    if len(path) == 0:
      path = '.'
    bm = BackupManager(backup_path = path, backup_file = file_out, quiet = options['q'], force = options['f'])
  else:
    bm = BackupManager(quiet = options['q'], force = options['f'])

  try:
    bm.restore(clean_backup = options['r'], clean_dirs = not options['n'])
  except Exception as e:
    print("Error: " + str(e), file = sys.stderr)
