<?php

namespace AppBundle\Controller\Ajax;

use AppBundle\Entity\User;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * GentelellaController.
 */
class AjaxNetworkController extends AjaxBaseController
{

    /**
     * Render Ajax page.
     *
     * @Route("ajax/network-table", name="app_ajax_networks_table")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxAction(Request $request){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        list($start, $length, $aOrder, $filter) = $this->parseData($request);

        $networks = $this->apiDevice->getAllNetworks($start, $length, $aOrder, $filter);

        if(empty($networks)){

            $networks = array();

        }

        $data =  [
            //"draw" =>  1,
            "recordsTotal" => $this->apiDevice->getCountOfAllNetworks(),
            "recordsFiltered" => $this->apiDevice->getCountOfAllNetworks($filter),
            "data" => $networks

        ];

        return new JsonResponse($data);

    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/available-networks", options={"expose"=true}, name="app_ajax_available_networks")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxAvailableDevicesForNetworkAction(Request $request){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        $networks = $this->apiDevice->getAllNetworks();

        $data = array();

        if(empty($networks)){
            $networks = array();
        }

        foreach ($networks as $network){

            $data[$network['name']] = $network['network_id'];

        }

        $data =  ["status" => "success", "data" => $data];

        return new JsonResponse($data);

    }

    /**
     * Render Device Detail Ajax page.
     *
     * @Route("ajax/network-detail/{id}", requirements={"id"="\d+"}, options={"expose"=true}, name="app_ajax_network_detail")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxNetworkDetailAction(Request $request, $id){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        $network = $this->apiDevice->getNetworkById($id);

        $devices = $this->apiDevice->getDevicesByNetworkId($id, 0, 1000);

        $deviceTemplate = $this->renderView('app/ajax/networkDetail.html.twig', [
            'network' => $network,
            'devices' => $devices
        ]);

        $data = array('html' => $deviceTemplate);

        return new JsonResponse($data);

    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/network-delete", options={"expose"=true}, name="app_ajax_remove_network")
     * @Method({"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxDeleteAction(Request $request){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        $this->denyAccessUnlessGranted(User::ROLE_NET_ADMIN);

        $data = json_decode($request->getContent(), true);
        $request->request->replace($data);

        $networkId = $request->request->get('networkId');

        try{

            $this->apiDevice->deleteNetwork($networkId);

            $data = array('status' => 'success', 'msg' => '');

        }catch (\Exception $e){

            $data = array('status' => 'failed', 'msg' => '');

        }

        return new JsonResponse($data);

    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/networks-delete", options={"expose"=true}, name="app_ajax_remove_networks")
     * @Method({"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxDeleteNetworksAction(Request $request){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        $this->denyAccessUnlessGranted(User::ROLE_NET_ADMIN);

        $data = json_decode($request->getContent(), true);
        $request->request->replace($data);

        $ids = $request->request->get('ids');

        try{

            $this->apiDevice->deleteNetworks($ids);

            $data = array('status' => 'success', 'msg' => implode(',', $ids));

        }catch (\Exception $e){

            $data = array('status' => 'failed', 'msg' => implode(',', $ids));

        }

        return new JsonResponse($data);

    }

    /**
     * @param $request
     * @return array
     */
    private function parseData($request){

        $parametersToValidate = $request->query->all();

        $start = $request->query->getInt('start');
        $length = $request->query->getInt('length');

        $search = $request->query->get('search');

        $columns = array(

            2 => 'name',
            3 => 'device_cnt',

        );

        // Individual column filtering
        $filterColumns = $request->query->get('columns');
        $search = $request->query->get('search');

        $filter = array();

        if(isset($search['value']) && !empty($search['value'])){

            $filter[$columns[ 2 ]] = '%' . $search['value'] . '%';

        }else{

            foreach ($filterColumns as $key => $column){

                $columnIdx = array_search( $column['data'], $columns );

                if($columnIdx && $column['search']['value'] != ''){

                    $filter[$columns[ $columnIdx ]] = '%' . $column['search']['value'] . '%';

                }

            }

        }

        $order = $request->query->get('order');
        $aOrder = array();

        foreach ($order as $item){

            $aOrder[$columns[$item['column']]] = $item['dir'];
        }

        return array($start, $length, $aOrder, $filter);

    }

}
