<?php

namespace AppBundle\Controller;

use AppBundle\Api\Device;
use AppBundle\Entity\User;
use AppBundle\Form\PrevalidationFormType;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Form\Util\ServerParams;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Class AppManagementController
 * @package AppBundle\Controller
 */
class PrevalidationController extends Controller
{

    /**
     * @Route("/prevalidation", name="app_prevalidation")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function indexAction(Request $request){

        //$this->denyAccessUnlessGranted(User::ROLE_DEVICE_ADMIN);

        $prevalidationForm = $this->createForm(PrevalidationFormType::class, null, array(

            'action' => $this->generateUrl('prevalidation_upload'),
            'method' => 'POST'

        ));


        return $this->render('app/pages/prevalidation/prevalidation.html.twig', [

            'prevalidationForm'      => $prevalidationForm->createView()

        ]);

    }

    /**
     * @Route("/prevalidation-upload", name="prevalidation_upload")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function prevalidateAction(Request $request){

        $this->denyAccessUnlessGranted(User::ROLE_DEVICE_ADMIN);

        $form = $this->createForm(PrevalidationFormType::class, null, array(

            'action' => $this->generateUrl('prevalidation_upload'),
            'method' => 'POST'

        ));

        try{
            $form->handleRequest($request);
        } catch (Exception $e){
            $this->addFlash(
            'error',
            'File upload failed.'
            );
            return $this->redirect($this->generateUrl('app_prevalidation'));
        }

        if ($form->isSubmitted() && $form->isValid()) {
            $file = $form->get('file')->getData();
            $fileName = $file->getClientOriginalName();

            // Move the file to the directory where brochures are stored
            try {
                $file->move(
                    $this->getParameter('upload_directory'),
                    $fileName
                );
            } catch (FileException $e) {
                $this->addFlash(
                    'error',
                    'File upload failed.'
                );
                return $this->redirect($this->generateUrl('app_prevalidation'));
            }

            $this->denyAccessUnlessGranted(User::ROLE_DEVICE_ADMIN);

            /** @var \AppBundle\Api\Device $apiDevice */
            $apiDevice = $this->container->get('cs_api_device');

            $err_msg = $apiDevice->setPrevalidationList($this->getParameter('upload_directory').'/'.$fileName);

            if(empty($err_msg)){

                $this->addFlash(
                    'notice',
                    'File was successfully uploaded. Routers were added to the list of pre-validated.'
                );

            }else{

                $this->addFlash(
                    'error',
                    "$err_msg"
                );

            }

            return $this->redirect($this->generateUrl('app_prevalidation'));

        }

    }

}
