<?php
namespace AppBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\ValidatorBuilder;

class NetworkFwRule extends AbstractType
{
    /**
     * @param FormBuilderInterface $builder
     * @param array                $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('enabled', CheckboxType::class, array(
                'label_render' => true,
                'label' => '<b style="padding-left: 5px;">Enable</b>',
                'widget_checkbox_label' => 'widget',
                //'label_format' => '%name%',
                //'attr' => array('class' => 'startdate span1 js-switch'),
                //'attr' => array('class' => 'startdate span1 '),
                'horizontal_input_wrapper_class' => "col-lg-2 col-lg-offset-2",
                //'horizontal_label_class' => 'col-md-2',
                //'horizontal_input_wrapper_class' => 'test'
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper' => false,
                'required' => false,
                //'empty_data' => true,
            ))
            ->add('protocol', ChoiceType::class, array(
                'choices' => array(
                    'TCP' => 'tcp',
                    'UDP' => 'udp',
                    'ICMP' => 'icmp',
                ),
                'horizontal_label_class' => 'col-md-2',
                //'horizontal_input_wrapper_class' => "col-lg-4",

                //'attr' => array('class' => 'startdate span1', 'style'=>"font-size: 12px;"),
                //'horizontal_label_class' => 'col-md-2',
                //'label_attr' => array('class'=>'col-sm-2 '),
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-2",
            ))
            ->add('ports', TextType::class, array(
                'required' => false,
                'render_optional_text' => false,
                'horizontal_label_class' => 'col-md-2',
                //'horizontal_input_wrapper_class' => "col-lg-4",
                //'attr' => array('class' => 'startdate span1'),
                //'horizontal_label_class' => 'col-md-1',
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-3",
            ));
    }


    /**
     * @param $data
     * @param $context
     * @return bool
     */
    public function validate($data, $context){

        $builder = new ValidatorBuilder();
        $validator = $builder->getValidator();

        $protocol = $data->getProtocol();
        $ports = $data->getPorts();

        $portsViolations = $validator->validate($ports, [new Assert\NotBlank()]);

        if ($protocol != 'icmp' && count($portsViolations) > 0) {

            $context->buildViolation('Port must be filled.')->addViolation();

        }

    }

        /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver){

        $resolver->setDefaults(array(
            'data_class' => \AppBundle\Entity\NetworkFwRule::class,
            'constraints' => array(new Assert\Callback(array($this, 'validate'))),
        ));

    }


    /**
     * @return string
     */
    public function getName()
    {
        return 'network_fw_rule';
    }

}